@@ -5,11 +5,11 @@ use warnings; # Duh >:)
 use Regexp::Assemble;
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.04';
 
 require Exporter;
 our @ISA = qw( Exporter );
-our @EXPORT_OK = qw(is_warning);
+our @EXPORT_OK = qw(is_warning not_warning);
 
 my $lines = [
 q{accept\(\)\ on\ closed\ socket\ .+?},
@@ -712,6 +712,11 @@ sub is_warning {
   return $string =~ $ra->re;
 }
 
+sub not_warning {
+  my $string = shift || return 1;
+  return $string !~ $ra->re;
+}
+
 'Danger! Danger! High Voltage!';
 __END__
 
@@ -729,13 +734,17 @@ String::Perl::Warnings - Determine if a string looks like a perl warning
     # Looks like a warning
   }
 
+  while( <> ) {
+    chomp;
+    next if not_warning($_);
+    # Looks like a warning
+  }
+
 =head1 DESCRIPTION
 
 String::Perl::Warnings can be used to determine if a string of arbitary text appears to look
 like a warning generated by perl.
 
-It has one function C<is_warning>.
-
 =head1 FUNCTIONS
 
 =over
@@ -745,6 +754,11 @@ It has one function C<is_warning>.
 Takes an arbitary string of text and returns a true value if the string looks like a perl warning,
 a false value otherwise.
 
+=item C<not_warning>
+
+Takes an arbitary string of text and returns a true value if the string does not look like a perl 
+warning and a false value otherwise.
+
 =back
 
 =head1 AUTHOR
